import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_iam._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@renovosolutions/cdk-library-managed-instance-role",
    "0.0.25",
    __name__[0:-6],
    "cdk-library-managed-instance-role@0.0.25.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
